@@ -133,6 +133,15 @@ Integer v_scalar_product_vectors_unequal_lungth(const vector<Integer>& a, const
     return v_scalar_product(trunc_a, trunc_b);
 }
 
+template <typename Integer, typename Number>
+Number v_scalar_product_vectors_unequal_lungth_mixed(const vector<Integer>& a, const vector<Number>& b) {
+    size_t n = std::min(a.size(), b.size());
+    Number ret = 0;
+    for(size_t i = 0; i < n; ++i)
+        ret += a[i] * b[i];
+    return ret;
+}
+
 // v = v * scalar
 template <typename Integer>
 void v_scalar_multiplication(vector<Integer>& v, const Integer scalar) {
@@ -812,15 +821,17 @@ inline renf_elem_class v_scalar_product(const vector<renf_elem_class>& av, const
 
     renf_elem_class ans = 0;
     size_t n = av.size();
-    renf_elem_class help;
+    // renf_elem_class help;
 
     for (size_t i = 0; i < n; ++i) {
-        if (av[i] != 0 && bv[i] != 0) {
-            ans += av[i] * bv[i];
-            /* help = av[i];
-            help *= bv[i]; // does not seem to help
-            ans += help;*/
-        }
+        // if(ans.is_rational()){
+            //help = av[i];
+            // help  *= bv[i];
+            ans += av[i]*bv[i];
+            //ans += help;
+        /*}
+        else
+            ans.iaddmul(av[i],bv[i]);*/
     }
     return ans;
 }
@@ -1491,9 +1502,13 @@ inline vector<string> to_string_vector(int argc, char* argv[]){
      return ret;
 }
 
+// It is not possible to use the following function qwith ret = renf_elem_class
 template<typename Val, typename Ret>
 void convert_vector_via_string(vector<Ret>& V, const vector<Val>& W){
 
+    if(using_renf<Ret>())
+        assert(false);
+
     stringstream bridge;
     bridge << W;
     V.resize(W.size());
